@@ -1,4 +1,4 @@
-__all__ = ['JMan', 'JManFb', 'JManError']
+__all__ = ['JMan', 'JManFb', 'JManError', 'JManErrorNoContent']
 
 import fdb
 from . import fb_consultes
